@@ -21,8 +21,10 @@ public:
   const std::string& GetZatUsername() const { return m_zatUsername; }
   const std::string& GetZatPassword() const { return m_zatPassword; }
   bool GetZatFavoritesOnly() const { return m_zatFavoritesOnly; }
+  bool GetSmartTV() const { return m_smartTV; }
   bool GetZatEnableDolby() const { return m_zatEnableDolby; }
   bool GetSkipStartOfProgramme() const { return m_skipStartOfProgramme; }
+  bool GetSkipEndOfProgramme() const { return m_skipEndOfProgramme; }
   int DrmLevel() const { return m_drmLevel; }
   const std::string GetParentalPin() const { return m_parentalPin; }
   int GetProvider() const { return m_provider; }
@@ -31,8 +33,10 @@ private:
   std::string m_zatUsername;
   std::string m_zatPassword;
   bool m_zatFavoritesOnly = false;
+  bool m_smartTV = false;
   bool m_zatEnableDolby = true;
   bool m_skipStartOfProgramme = true;
+  bool m_skipEndOfProgramme = true;
   int m_drmLevel = 0;
   std::string m_parentalPin;
   int m_provider = 0;
